@@ -1,4 +1,5 @@
-from deatool.scrips.run import run
+from deatool.scripts.run import run
+
 
 if __name__ == '__main__':
     run()
\ No newline at end of file
